==> gradle-9.2.0-20250906012755+0000-src.zip: gradle-9.2.0-20250906012755+0000/testing/performance/build.gradle.kts <==
plugins {
    id("gradlebuild.internal.java")
    id("gradlebuild.performance-testing")
    id("gradlebuild.performance-templates")
}

description = "Performance tests for the Gradle build tool"

dependencies {
    performanceTestImplementation(projects.baseServices)
    performanceTestImplementation(projects.core)
    performanceTestImplementation(projects.internalTesting)
    performanceTestImplementation(projects.stdlibJavaExtensions)
    performanceTestImplementation(projects.toolingApi)

    performanceTestImplementation(testFixtures(projects.toolingApi))

    performanceTestImplementation(libs.commonsLang)
    performanceTestImplementation(libs.commonsIo)
    performanceTestImplementation(libs.gradleProfiler)
    performanceTestImplementation(libs.jettyServer)
    performanceTestImplementation(libs.jettyWebApp)
    performanceTestImplementation(libs.junit)
    performanceTestImplementation(libs.servletApi)

    performanceTestRuntimeOnly(projects.coreApi)
    performanceTestRuntimeOnly(libs.jetty)

    performanceTestDistributionRuntimeOnly(projects.distributionsFull) {
        because("All Gradle features have to be available.")
    }
    performanceTestLocalRepository(projects.toolingApi) {
        because("IDE tests use the Tooling API.")
    }
}

dependencyAnalysis {
    issues {
        onUnusedDependencies {
            exclude(libs.junitJupiter)
        }

        ignoreSourceSet(sourceSets.performanceTest.name)
    }
}

errorprone {
    nullawayEnabled = true
}

==> gradle-9.5.0-20260221010500+0000-src.zip: gradle-9.5.0-20260221010500+0000/testing/performance/build.gradle.kts <==
plugins {
    id("gradlebuild.internal.java")
    id("gradlebuild.performance-testing")
    id("gradlebuild.performance-templates")
}

description = "Performance tests for the Gradle build tool"

dependencies {
    performanceTestImplementation(projects.baseServices)
    performanceTestImplementation(projects.core)
    performanceTestImplementation(projects.internalIntegTesting)
    performanceTestImplementation(projects.internalTesting)
    performanceTestImplementation(projects.stdlibJavaExtensions)
    performanceTestImplementation(projects.toolingApi)

    performanceTestImplementation(testFixtures(projects.toolingApi))

    performanceTestImplementation(libs.commonsLang)
    performanceTestImplementation(libs.commonsIo)
    performanceTestImplementation(testLibs.gradleProfiler)
    performanceTestImplementation(testLibs.jettyServer)
    performanceTestImplementation(testLibs.jettyWebApp)
    performanceTestImplementation(testLibs.junit)
    performanceTestImplementation(testLibs.servletApi)

    performanceTestRuntimeOnly(projects.coreApi)
    performanceTestRuntimeOnly(testLibs.jetty)

    performanceTestDistributionRuntimeOnly(projects.distributionsFull) {
        because("All Gradle features have to be available.")
    }
    performanceTestLocalRepository(projects.toolingApi) {
        because("IDE tests use the Tooling API.")
    }
}

dependencyAnalysis {
    issues {
        onUnusedDependencies {
            exclude(testLibs.junitJupiter)
        }

        ignoreSourceSet(sourceSets.performanceTest.name)
    }
}

errorprone {
    nullawayEnabled = true
}
